Index: trunk/psModules/src/imcombine/pmSubtractionStamps.h
===================================================================
--- trunk/psModules/src/imcombine/pmSubtractionStamps.h	(revision 25101)
+++ trunk/psModules/src/imcombine/pmSubtractionStamps.h	(revision 26035)
@@ -24,4 +24,5 @@
     psArray *flux;                      ///< Fluxes for possible stamps (or NULL)
     int footprint;                      ///< Half-size of stamps
+    float sysErr;                       ///< Systematic error
 } pmSubtractionStampList;
 
@@ -31,5 +32,6 @@
                                                     const psRegion *region, // Region for stamps, or NULL
                                                     int footprint, // Half-size of stamps
-                                                    float spacing // Rough average spacing between stamps
+                                                    float spacing, // Rough average spacing between stamps
+                                                    float sysErr  // Relative systematic error or NAN
     );
 
@@ -68,5 +70,5 @@
     psKernel *image1;                   ///< Reference image postage stamp
     psKernel *image2;                   ///< Input image postage stamp
-    psKernel *variance;                 ///< Variance image postage stamp, or NULL
+    psKernel *weight;                   ///< Weight image (1/variance) postage stamp, or NULL
     psArray *convolutions1;             ///< Convolutions of image 1 for each kernel component, or NULL
     psArray *convolutions2;             ///< Convolutions of image 2 for each kernel component, or NULL
@@ -91,4 +93,5 @@
                                                 int footprint, ///< Half-size for stamps
                                                 float spacing, ///< Rough spacing for stamps
+                                                float sysErr,  ///< Relative systematic error in images
                                                 pmSubtractionMode mode ///< Mode for subtraction
     );
@@ -103,4 +106,5 @@
                                                int footprint, ///< Half-size for stamps
                                                float spacing, ///< Rough spacing for stamps
+                                               float sysErr,  ///< Systematic error in images
                                                pmSubtractionMode mode ///< Mode for subtraction
     );
@@ -115,4 +119,5 @@
     int footprint,                      ///< Half-size for stamps
     float spacing,                      ///< Rough spacing for stamps
+    float sysErr,                       ///< Systematic error in images
     pmSubtractionMode mode              ///< Mode for subtraction
     );
@@ -127,4 +132,5 @@
     int footprint,                      ///< Half-size for stamps
     float spacing,                      ///< Rough spacing for stamps
+    float sysErr,                       ///< Systematic error in images
     pmSubtractionMode mode              ///< Mode for subtraction
     );
